%%
%% This is file `fancyref-xetex-xepersian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% xepersian.dtx  (with options: `table,fancyref-xetex-xepersian.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2008--2026  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 
%% \CheckSum{10865}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{fancyref-xetex-xepersian.def}[2018/09/29 v0.1 xepersian adaptations for fancyref package for XeTeX engine]
\renewcommand*{\Frefchapname}{\chaptername}
\renewcommand*{\Frefenumname}{%
  \if@RTL
فقره%
  \else
    Item%
  \fi
}
\renewcommand*{\Frefeqname}{%
  \if@RTL
معادله%
  \else
    Equation%
  \fi
}
\renewcommand*{\Freffigname}{\figurename}
\renewcommand*{\Freffnname}{%
  \if@RTL
زیرنویس%
  \else
    Footnote%
  \fi
}
\renewcommand*{\Frefonname}{%
  \if@RTL
در%
  \else
    On%
  \fi
}
\renewcommand*{\Frefpgname}{\pagename}
\renewcommand*{\Frefsecname}{%
  \if@RTL
قسمت%
  \else
    Section%
  \fi
}
\renewcommand*{\Frefseename}{%
  \if@RTL
ببینید%
  \else
    See%
  \fi
}
\renewcommand*{\Freftabname}{\tablename}
\renewcommand*{\Freffigshortname}{%
  \if@RTL
    \Freffigname
  \else
    Fig.%
  \fi
}
\renewcommand*{\Frefpgshortname}{%
  \if@RTL
    \Frefpgname
  \else
    P.%
  \fi
}
\renewcommand*{\Freftabshortname}{%
  \if@RTL
    \tablename
  \else
    Tab.%
  \fi
}
\renewcommand*{\frefchapname}{%
  \if@RTL
    \Frefchapname
  \else
    \MakeLowercase{\Frefchapname}%
\fi
}
\renewcommand*{\frefenumname}{%
  \if@RTL
    \Frefenumname
  \else
    \MakeLowercase{\Frefenumname}%
  \fi
}
\renewcommand*{\frefeqname}{%
  \if@RTL
    \Frefeqname
  \else
    \MakeLowercase{\Frefeqname}%
  \fi
}
\renewcommand*{\freffigname}{%
  \if@RTL
    \Freffigname
  \else
    \MakeLowercase{\Freffigname}%
  \fi
}
\renewcommand*{\freffnname}{%
  \if@RTL
    \Freffnname
  \else
    \MakeLowercase{\Freffnname}%
  \fi
}
\renewcommand*{\frefonname}{%
  \if@RTL
    \Frefonname
  \else
    \MakeLowercase{\Frefonname}%
  \fi
}
\renewcommand*{\frefpgname}{%
  \if@RTL
    \Frefpgname
  \else
    \MakeLowercase{\Frefpgname}%
  \fi
}
\renewcommand*{\frefsecname}{%
  \if@RTL
    \Frefsecname
  \else
    \MakeLowercase{\Frefsecname}%
  \fi
}
\renewcommand*{\frefseename}{%
  \if@RTL
    \Frefseename
  \else
    \MakeLowercase{\Frefseename}%
  \fi
}
\renewcommand*{\freftabname}{%
  \if@RTL
    \Freftabname
  \else
    \MakeLowercase{\Freftabname}%
  \fi
}
\renewcommand*{\freffigshortname}{%
  \if@RTL
    \Freffigshortname
  \else
    \MakeLowercase{\Freffigshortname}%
  \fi
}
\renewcommand*{\frefpgshortname}{%
  \if@RTL
    \Frefpgshortname
  \else
    \MakeLowercase{\Frefpgshortname}%
  \fi
}
\renewcommand*{\freftabshortname}{%
  \if@RTL
    \Freftabshortname
  \else
    \MakeLowercase{\Freftabshortname}%
  \fi
}
\endinput
%%
%% End of file `fancyref-xetex-xepersian.def'.
